Example fish survey datasets used throughout the package documentation and examples.
Format
pcod: Trawl survey data for Pacific Cod in Queen Charlotte Sound. A
data frame.
pcod_2011: A version of pcod for years 2011 and after (smaller
for speed). A data frame.
pcod_mesh_2011: A mesh pre-built for pcod_2011 for examples. A
list of class sdmTMBmesh.
qcs_grid: A 2 x 2 km prediction grid for Queen Charlotte Sound. A data
frame.
dogfish: Trawl survey data for Pacific Spiny Dogfish on West Coast
Vancouver Island. A data frame.
yelloweye: Survey data for Yelloweye Rockfish from the Hard Bottom
Longline Survey (South) off West Coast Vancouver Island.
hbll_s_grid: A survey domain grid corresponding to yelloweye. A data frame.
wcvi_grid: A survey domain grid corresponding to dogfish. A data frame.