This method updates an sdmTMB model with new arguments while automatically handling the mesh object to avoid environment issues when loading models from saved files.
Usage
# S3 method for class 'sdmTMB'
update(object, formula., ..., evaluate = TRUE)Value
An updated sdmTMB model object (if evaluate = TRUE) or
an unevaluated call (if evaluate = FALSE).
Details
Unless control is supplied, the updated model reuses the fitted model's
sdmTMBcontrol() settings, including its backend, regardless of the
current sdmTMB.backend option. A supplied control replaces these
settings, including the backend (e.g.,
update(fit, control = sdmTMBcontrol(backend = "rtmb"))).