This method updates an sdmTMB model with new arguments while automatically handling the mesh object to avoid environment issues when loading models from saved files.
Usage
# S3 method for class 'sdmTMB'
update(object, formula., ..., evaluate = TRUE)This method updates an sdmTMB model with new arguments while automatically handling the mesh object to avoid environment issues when loading models from saved files.
# S3 method for class 'sdmTMB'
update(object, formula., ..., evaluate = TRUE)